%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Histogram of Data
%
% The intention of this script is to test some basic functions in FreeMat
% that seem to work for most people but not for a few. If you are having 
% troubles getting FreeMat to draw the bars using this simple script let
% me know and we'll see what we can do to figure out what the problem is.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


clear 'all';                   % tells FreeMat to 'forget' previous variable assignments, clean the board!

xbinedges = 0:5:50;            % bin edges for the histogram                      
ybindummy = 0.0.*xbinedges;    % heights of the bins set to 0 for a dummy variable
plotheight = 5;
numbins = length(xbinedges) -1;

c1t = [.3 .2 .6];              % defines custom color label for data set 1 text, play with these
c2t = [.3 .3 .3];              % defines custom color label for data set 2
c1 = [.5 .4 .7];               % defines custom color label for data set 1 bars, play with these
c2 = [.5 .5 .5];               % defines custom color label for data set 2


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Starting the Plot
%
% The general plan is to create a plot window and then use the patch command to draw the histogram
%  bars where I want them. To do this I start by drawing a blank plot. The axis command allows me to 
%  choose the plot width and height.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plot(xbinedges,ybindummy,'b-', 0,0,'k-');
axis([xbinedges(1),xbinedges(numbins+1),0,plotheight]); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Making a patch....
%
% This script is expressly created to verify that the patch 
% function works within your FreeMat installation.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

xpts1 = [5,25,25,5];
ypts1 = [0,0,2,2];
xpts2 = [15,30,30,15];
ypts2 = [0,0,3,3];

patch(xpts2,ypts2,c2);
patch(xpts1,ypts1,c1);


line([40,40],[0,4]);
text(38,2,'this is some text','color',c1t,'rotation', 90,'fontsize', 16);

                              
xlabel('Number of pies eaten in 2013');                         %  label the x-axis
ylabel('Number of people eating that many pies');               %  label the y-axis
title('Pie Eating in Oregon during 2013');                      %  Give the plot a title at the top

